addTerm: #################################################################...

Description Usage Arguments Value

View source: R/TaxonomyManage.R

Description

################################################################# This file has funtions for managing taxonomy in a tree structure ################################################################# ################################################################# function to add a word to the taxonomy

Usage

1
addTerm(taxtree, child, path = NULL)

Arguments

taxtree

- the taxonomy tree to which word needs to be added

child

- word to be added to taxonomy tree

parent

- parent to which term will be added as child, if parent is NULL then word is added to Root of tree

Value

updated taxonomy tree


siddheshdhuri/TaxonomyTree documentation built on May 29, 2019, 9:58 p.m.