Description Usage Arguments Value
View source: R/TaxonomyManage.R
################################################################# This file has funtions for managing taxonomy in a tree structure ################################################################# ################################################################# function to add a word to the taxonomy
1 |
taxtree |
- the taxonomy tree to which word needs to be added |
child |
- word to be added to taxonomy tree |
parent |
- parent to which term will be added as child, if parent is NULL then word is added to Root of tree |
updated taxonomy tree
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.